@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -663,7 +663,7 @@ func TestConnCollection_get(t *testing.T) {
 				logr:       log.New("test"),
 			}
 
-			got, err := c.get(context.Background(), tt.args.conf)
+			got, err := c.get(t.Context(), tt.args.conf)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf(
 					"ConnCollection.get() error = %v, wantErr %v",
@@ -892,7 +892,7 @@ func TestConnCollection_newConn(t *testing.T) {
 					logr:       log.New("test"),
 				}
 
-				got, err := c.newConn(context.Background(), tt.args.conf)
+				got, err := c.newConn(t.Context(), tt.args.conf)
 				if (err != nil) != tt.wantErr {
 					t.Fatalf(
 						"ConnCollection.newConn() error = %v, wantErr %v",
